@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Catalogue
-Version : 1.2.0
+Version : 1.3.0
 Author  : Stefano Covino
-Date    : 26/07/2013
+Date    : 02/08/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -21,11 +21,13 @@ History : (29/09/2010) First named version.
         : (15/04/2013) SDSS query script.
         : (06/05/2013) SDSS class.
         : (26/07/2013) APASS class
+        : (02/08/2014) SIMBAD name resolver.
 """
 
 
 
 __all__ = ['AGNOptRefStarsClass', 'APASSClass', 'AstroWiseStandardStarsClass', 'BrightStarClass',
            'CatalogueConstants', 'GetVizierCat', 'NIRStandardStarsClass','ParseVisierCat',
-           'SDSSClass', 'StetsonJohnsonStandardStarsClass', 'TWOMASSClass', 'USNOB1Class', 'USNOClass']
+           'SDSSClass', 'SimbadNameClass', 'StetsonJohnsonStandardStarsClass', 'TWOMASSClass', 
+           'USNOB1Class', 'USNOClass']
 
