@@ -2,10 +2,10 @@
 
 Context : SRP
 Module  : SRPFiles.py
-Version : 1.7.3
+Version : 1.7.4
 Status  : approved
 Author  : Stefano Covino, Nico Cucchiara
-Date    : 05/02/2012
+Date    : 21/05/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/~covino
 Purpose : Collection of constants and functions for file managements.
@@ -29,6 +29,7 @@ History : (20/05/2003) First version.
         : (21/03/2011) Better coding for extinction routines.
         : (16/08/2011) Absolute pathes correctly managed.
         : (05/02/2012) Better path management.
+        : (21/05/2012) pipe function commented.
 """
 
 
@@ -260,23 +261,23 @@ def IsReadable (filename):
 
 
 # SRP pipe
-if sys.version_info[0] >= 2 and sys.version_info[1] >= 6:
-    def SRPPipe (file):
-        f = subprocess.Popen(file,stdin=subprocess.PIPE,stdout=subprocess.PIPE,stderr=subprocess.PIPE,shell=True,close_fds=True)
-        ky = f.stdout.read()
-        estatus = f.wait()
-        del f
-        if os.WEXITSTATUS (estatus):
-            return None
-        else:
-            return ky
-else:
-    def SRPPipe (file):
-        f = popen2.Popen4(file)
-        ky = f.fromchild.read()
-        estatus = f.wait()
-        del f
-        if os.WEXITSTATUS (estatus):
-            return None
-        else:
-            return ky
+#if sys.version_info[0] >= 2 and sys.version_info[1] >= 6:
+#    def SRPPipe (file):
+#        f = subprocess.Popen(file,stdin=subprocess.PIPE,stdout=subprocess.PIPE,stderr=subprocess.PIPE,shell=True,close_fds=True)
+#        ky = f.stdout.read()
+#        estatus = f.wait()
+#        del f
+#        if os.WEXITSTATUS (estatus):
+#            return None
+#        else:
+#            return ky
+#else:
+#    def SRPPipe (file):
+#        f = popen2.Popen4(file)
+#        ky = f.fromchild.read()
+#        estatus = f.wait()
+#        del f
+#        if os.WEXITSTATUS (estatus):
+#            return None
+#        else:
+#            return ky
