@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Fits.py
-Version : 1.7.1
+Version : 1.8.0
 Author  : Stefano Covino
-Date    : 21/01/2014
+Date    : 27/10/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -26,6 +26,7 @@ History : (23/05/2010) First version.
         : (19/08/2013) Possiblity to read different extensions and original BITPIX saved.
         : (16/10/2013) Frame center in pixel.
         : (21/01/2014) Possibility to get statistixsw for just a subregion.
+        : (27/10/2014) Sextractor source finding.
 """
 
 import os
@@ -40,6 +41,7 @@ import FitsConstants as FitsConstants
 
 from SRP.SRPFrames.SourceObjectsClass import SourceObjects
 from SRP.SRPFrames.EclipseObjectClass import EclipseObjects
+from SRP.SRPFrames.SexObjectClass import SexObjects
 from SRP.SRPFrames.Pixel2WCS import Pixel2WCS
 
 
@@ -53,7 +55,8 @@ class FitsImage:
         self.NAXIS = GetHeaderValue(fitsfile,'NAXIS',extension)[0]
         self.List = []
         self.NativeSourcesFlag = False
-        self.EclipseSorcesFlag = False
+        self.EclipseSourcesFlag = False
+        self.SexSourcesFlag = False
 
 
     def Sources(self, threshold=5.0, filtsing=3):
@@ -69,6 +72,7 @@ class FitsImage:
         self.List = slist.ListEntries
         self.NativeSourcesFlag = True
         self.EclipseSourcesFlag = False
+        self.SexSourcesFlag = False
         return len(self.List)
         
         
@@ -79,6 +83,9 @@ class FitsImage:
         elif self.EclipseSourcesFlag:
             self.List.sort()
             self.List.reverse()
+        elif self.SexSourcesFlag:
+            self.List.sort()
+            self.List.reverse()
         
         
     def GetFrameSizePix(self):
@@ -116,6 +123,29 @@ class FitsImage:
         self.List = elist.ListEntries
         self.EclipseSourcesFlag = True
         self.NativeSourcesFlag = False
+        self.SexSourcesFlag = False
+        return len(self.List)
+
+
+    def SexSources(self,level=3.0):
+        elist = SexObjects(self.Name,level)
+        elist.FindSexObjects()
+        srclist = []
+        for i in elist.ListEntries:
+            srclist.append((i.X,i.Y))
+        try:
+            coolist = Pixel2WCS(self.Header,srclist)
+        except AttributeError:
+            coolist = []
+            for ii in range(len(srclist)):
+                coolist.append((0.,0.))
+        for i,l in zip(elist.ListEntries,coolist):
+            i.RA = l[0]
+            i.DEC = l[1]
+        self.List = elist.ListEntries
+        self.SexSourcesFlag = True
+        self.EclipseSourcesFlag = False
+        self.NativeSourcesFlag = False
         return len(self.List)
 
 
@@ -142,8 +172,12 @@ class FitsImage:
             for i in range(len(self.List)):
                 self.List[i].Id = i+1
                 msg = msg + str(self.List[i])
+        # Sex
+        elif self.SexSourcesFlag:
+            for i in range(len(self.List)):
+                msg = msg + str(self.List[i])
         return msg
-        
+    
 
     def Skycat(self, outname='SRP.cat'):
         msg = ''
@@ -160,6 +194,10 @@ class FitsImage:
         # Eclipse
         elif self.EclipseSourcesFlag:
             msg = msg + "Id\tX\tY\tNpix\tMin\tMax\tFW_X\tFW_Y\tFWHM\tFlux\tRA\tDEC\n"
+        # Sex
+        elif self.SexSourcesFlag:
+            msg = msg + "Id\tX\tY\tNpix\tEllipticity\tFlux\tPeak\tFlag\tRA\tDEC\n"
+        
         msg = msg + "---------\n"
         msg = msg + str(self)
         msg = msg + "EOD\n"
