@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Fits.py
-Version : 1.1.0
+Version : 1.2.0
 Author  : Stefano Covino
-Date    : 14/02/2012
+Date    : 16/12/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -14,7 +14,7 @@ Remarks :
 
 History : (23/05/2010) First version.
         : (14/02/2012) Possibility to read extensions.
-
+        : (16/12/2014) Manage wrong FITS headers.
 """
 
 import pyfits
@@ -25,6 +25,7 @@ def GetHeader (fitsfile, ext=0):
         hdr = pyfits.open(fitsfile)
     except IOError:
         return None,FitsConstants.FitsFileNotFound
+    hdr[ext].verify('silentfix+ignore')
     heder = hdr[ext].header
     return heder,FitsConstants.FitsHeaderFound
     
