@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames.py
-Version : 1.8.0
+Version : 1.8.1
 Author  : Stefano Covino
-Date    : 30/10/2014
+Date    : 09/12/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -37,6 +37,7 @@ History : (27/09/2010) First version.
         : (16/10/2013) Better computation of frame center.
         : (16/07/2014) Deal with non standard FITS headers.
         : (30/10/2014) Sextractor source finding.
+        : (09/12/2014) Better choice of threshold for sextractor source finding.
 """
 
 
@@ -256,7 +257,7 @@ class Astrometry:
 
 
 
-    def GetSexSources(self, maxobjs=15, thre=10, cleanperc=1.):
+    def GetSexSources(self, maxobjs=15, thre=100, cleanperc=1.):
             soglia = copy.copy(thre)
             while len(self.List) < maxobjs and soglia > 0.1:
                 self.FitsFrame.SexSources(soglia)
@@ -265,9 +266,11 @@ class Astrometry:
                 if len(self.FitsFrame.List) >= maxobjs:
                     self.List = self.FitsFrame.List[:maxobjs]
                 else:
-                    if soglia-1 > 3:
+                    if soglia > 10:
+                        soglia = soglia - 5
+                    elif 3 <= soglia < 10:
                         soglia = soglia - 1
-                    elif 1 < soglia <= 3:
+                    elif 1 <= soglia < 3:
                         soglia = soglia - 0.5
                     else:
                         soglia = soglia - 0.1
