@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames
-Version : 1.0.1
+Version : 1.0.2
 Author  : Stefano Covino
-Date    : 31/08/2012
+Date    : 27/10/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -19,7 +19,7 @@ History : (31/08/2012) First named version.
 
 
 __all__ = ['AstrometryClass', 'EclipseConstants', 'EclipseObjectClass', 
-           'getCenterRADEC', 'Pixel2WCS', 'SExtractorConstants', 'SourceObjectsClass', 
-           'WCS2Pixel']
+           'getCenterRADEC', 'Pixel2WCS', 'SexConstants', 'SexObjectClass',
+           'SExtractorConstants', 'SourceObjectsClass', 'WCS2Pixel']
 
 
