@@ -1,7 +1,7 @@
 """ Utility functions and classes for SRP
 
 Context : SRP
-Module  : Math.py
+Module  : Math
 Version : 1.0.0
 Author  : Stefano Covino
 Date    : 25/06/2010
