@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Math
-Version : 1.1.1
+Version : 1.1.2
 Author  : Stefano Covino
-Date    : 20/09/2012
+Date    : 18/11/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -20,11 +20,14 @@ History : (29/09/2010) First named version.
         : (18/02/2012) Sky functions moved to SRPSky.
         : (23/08/2012) New angular distance function.
         : (20/09/2012) Angular phasing function.
+        : (18/11/2014) Doppler factor function.
 """
 
 
-__all__ = ['AngularDistance', 'AstroAngleInput', 'AstroCoordInput', 'AstroMagInput', 'CartesiamCoordAmpRotoTranslation', 
-            'CartesianDistance', 'CartesianVectorClass', 'FastAngularDistance', 'InverseCartesiamCoordAmpRotoTranslation', 
-            'MinDist', 'PhaseAngle', 'PointClass', 'PointMatch', 'TriangleClass', 'TriangleMatch']
+__all__ = ['AngularDistance', 'AstroAngleInput', 'AstroCoordInput', 'AstroMagInput',
+           'CartesiamCoordAmpRotoTranslation','CartesianDistance', 'CartesianVectorClass',
+           'DopplerFactor','FastAngularDistance', 'InverseCartesiamCoordAmpRotoTranslation',
+           'LorentzFactor','MinDist', 'PhaseAngle', 'PointClass', 'PointMatch', 'TriangleClass',
+           'TriangleMatch']
 
 
