@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.1.49
+Version : 1.1.55
 Author  : Stefano Covino
-Date    : 04/11/2014
+Date    : 22/12/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -124,6 +124,12 @@ History : (28/09/2010) First named version.
         : (27/10/2014) V. 3.12.1b1.
         : (30/10/2014) V. 3.12.1b2.
         : (04/11/2014) V. 3.12.1.
+        : (11/11/2014) V. 3.12.2b1.
+        : (18/11/2014) V. 3.12.2b2.
+        : (19/11/2014) V. 3.12.2b3.
+        : (09/12/2014) V. 3.12.2b4.
+        : (16/12/2014) V. 3.12.2b5.
+        : (22/12/2014) V. 3.12.2.
 """
 
 
@@ -138,6 +144,6 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.12.1'
+__version__ = '3.12.2'
 
 #
\ No newline at end of file
